@@ -1,5 +1,7 @@
-from .encryption import Encryption
-from .projects import DonationProject, Participant, QuestionnaireResponse
+from .encryption import *
+from .projects import (
+    DonationProject, Participant, QuestionnaireResponse, ResearchProfile
+)
 from .data_donations import (
     DonationBlueprint, ZippedBlueprint, DataDonation, DonationInstruction
 )
